builders library
The file based builders that are available and the code generators
Functions
-
pageRoutes(
BuilderOptions options) → Builder - Default builder Will check for framework config value
The file based builders that are available and the code generators